@@ -1,14 +1,14 @@
 #!/usr/bin/env perl
 
+# Monitor the MIDI messages of the given port.
+
 use strict;
 use warnings;
-
 use MIDI::RtController;
 
-my $in  = $ARGV[0] || 'oxy';
-my $out = $ARGV[1] || 'gs';
+my $in = $ARGV[0] || die "Usage: perl $0 midi-in-port";
 
-my $rtc = MIDI::RtController->new( input => $in, output => $out );
+my $rtc = MIDI::RtController->new( input => $in, output => $in );
 
 $rtc->add_filter(
     'echo',
